pub fn router_with_backend_arc_and_options(
backend: Arc<dyn RestBackend>,
options: RestRouterOptions,
) -> RouterExpand description
Builds a REST router from a shared backend trait object and options.
pub fn router_with_backend_arc_and_options(
backend: Arc<dyn RestBackend>,
options: RestRouterOptions,
) -> RouterBuilds a REST router from a shared backend trait object and options.